@@ -131,6 +131,8 @@ ev_pixbuf_cache_finalize (GObject *object)
 	g_free (pixbuf_cache->prev_job);
 	g_free (pixbuf_cache->job_list);
 	g_free (pixbuf_cache->next_job);
+
+	G_OBJECT_CLASS (ev_pixbuf_cache_parent_class)->finalize (object);
 }
 
 static void
@@ -195,6 +197,8 @@ ev_pixbuf_cache_dispose (GObject *object)
 	for (i = 0; i < PAGE_CACHE_LEN (pixbuf_cache); i++) {
 		dispose_cache_job_info (pixbuf_cache->job_list + i, pixbuf_cache);
 	}
+
+	G_OBJECT_CLASS (ev_pixbuf_cache_parent_class)->dispose (object);
 }
 
 
@@ -229,6 +233,7 @@ job_finished_cb (EvJob         *job,
 	job_info = find_job_cache (pixbuf_cache, job_render->rc->page);
 
 	copy_job_to_job_info (job_render, job_info, pixbuf_cache);
+
 	g_signal_emit (pixbuf_cache, signals[JOB_FINISHED], 0);
 }
 
@@ -448,7 +453,6 @@ copy_job_to_job_info (EvJobRender   *job_render,
 		job_info->selection_region = gdk_region_copy (job_render->selection_region);
 		job_info->selection = g_object_ref (job_render->selection);
 		g_assert (job_info->selection_points.x1 >= 0);
-		job_info->points_set = TRUE;
 	}
 
 	if (job_info->job) {
@@ -681,7 +685,6 @@ ev_pixbuf_cache_get_pixbuf (EvPixbufCache *pixbuf_cache,
 	if (job_info->job &&
 	    EV_JOB (job_info->job)->finished) {
 		copy_job_to_job_info (EV_JOB_RENDER (job_info->job), job_info, pixbuf_cache);
-		g_signal_emit (pixbuf_cache, signals[JOB_FINISHED], 0);
 	}
 
 	return job_info->pixbuf;
@@ -701,7 +704,6 @@ ev_pixbuf_cache_get_link_mapping (EvPixbufCache *pixbuf_cache,
 	if (job_info->job &&
 	    EV_JOB (job_info->job)->finished) {
 		copy_job_to_job_info (EV_JOB_RENDER (job_info->job), job_info, pixbuf_cache);
-		g_signal_emit (pixbuf_cache, signals[JOB_FINISHED], 0);
 	}
 
 	return job_info->link_mapping;
@@ -724,7 +726,6 @@ ev_pixbuf_cache_get_image_mapping (EvPixbufCache *pixbuf_cache,
 	if (job_info->job &&
 	    EV_JOB (job_info->job)->finished) {
 		copy_job_to_job_info (EV_JOB_RENDER (job_info->job), job_info, pixbuf_cache);
-		g_signal_emit (pixbuf_cache, signals[JOB_FINISHED], 0);
 	}
 
 	return job_info->image_mapping;
@@ -782,7 +783,6 @@ ev_pixbuf_cache_get_text_mapping (EvPixbufCache *pixbuf_cache,
 	if (job_info->job &&
 	    EV_JOB (job_info->job)->finished) {
 		copy_job_to_job_info (EV_JOB_RENDER (job_info->job), job_info, pixbuf_cache);
-		g_signal_emit (pixbuf_cache, signals[JOB_FINISHED], 0);
 	}
 	
 	return job_info->text_mapping;
