@@ -104,9 +104,12 @@ struct _EvView {
 	gint end_page;
 	gint current_page;
 
-	int rotation;
-	double scale;
-	int spacing;
+	gint rotation;
+	gdouble scale;
+	gint spacing;
+	gdouble dpi;
+	gdouble max_scale;
+	gdouble min_scale;
 
 	gboolean loading;
 	gboolean continuous;
@@ -114,6 +117,7 @@ struct _EvView {
 	gboolean fullscreen;
 	gboolean presentation;
 	EvSizingMode sizing_mode;
+	cairo_surface_t *loading_text;
 
 	/* Presentation */
 	EvPresentationState presentation_state;
@@ -157,6 +161,8 @@ struct _EvViewClass {
 					   EvScrollType   scroll,
 					   gboolean        horizontal);
 	void    (*zoom_invalid)		  (EvView         *view);
+	void    (*handle_link)		  (EvView         *view,
+					   EvLink         *link);
 	void    (*external_link)	  (EvView         *view,
 					   EvLinkAction   *action);
 	void    (*popup_menu)		  (EvView         *view,
