@@ -27,10 +27,15 @@
 #include <gtk/gtkmain.h>
 #include <stdlib.h>
 #include <string.h>
+
+#if WITH_GNOME
 #include <libgnome/gnome-program.h>
 #include <libgnomeui/gnome-ui-init.h>
 #include <libgnomeui/gnome-app-helper.h>
 #include <libgnomeui/gnome-authentication-manager.h>
+#endif
+
+#include <libgnomevfs/gnome-vfs-init.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
 #ifdef ENABLE_DBUS
@@ -46,6 +51,7 @@ static gboolean preview_mode = FALSE;
 static gboolean fullscren_mode = FALSE;
 static gboolean presentation_mode = FALSE;
 static gboolean unlink_temp_file = FALSE;
+static gchar   *print_settings;
 static const char **file_arguments = NULL;
 
 static const GOptionEntry goption_options[] =
@@ -55,6 +61,7 @@ static const GOptionEntry goption_options[] =
 	{ "presentation", 's', 0, G_OPTION_ARG_NONE, &presentation_mode, N_("Run evince in presentation mode"), NULL },
 	{ "preview", 'w', 0, G_OPTION_ARG_NONE, &preview_mode, N_("Run evince as a previewer"), NULL },
 	{ "unlink-tempfile", 'u', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &unlink_temp_file, NULL, NULL },
+	{ "print-settings", 't', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_FILENAME, &print_settings, NULL, NULL },
 	{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &file_arguments, NULL, N_("[FILE...]") },
 	{ NULL }
 };
@@ -66,6 +73,24 @@ value_free (GValue *value)
 	g_free (value);
 }
 
+/**
+ * arguments_parse:
+ *
+ * Parses the arguments and creates a #GHashTable with this data.
+ *
+ *  key                 ->  value
+ *
+ *  dislay              ->  display at the default screen.
+ *  screen              ->  screen number.
+ *  page-label          ->  only if the page label argument has been passed,
+ *                          the page of the document to display.
+ *  mode                ->  only if the view mode is one of the availables,
+ *                          the view mode.
+ *  unlink-temp-file    ->  only if the view mode is preview mode and
+ *                          unlink-temp-file has been passed, unlink-temp-file.
+ *
+ * Returns: a pointer into #GHashTable with data from the arguments.
+ */
 static GHashTable *
 arguments_parse (void)
 {
@@ -104,6 +129,9 @@ arguments_parse (void)
 		g_value_set_string (value, ev_page_label);
 
 		g_hash_table_insert (args, g_strdup ("page-label"), value);
+
+		g_free (ev_page_label);
+		ev_page_label = NULL;
 	}
 
 	if (fullscren_mode)
@@ -131,6 +159,18 @@ arguments_parse (void)
 				     value);
 	}
 
+	if (mode == EV_WINDOW_MODE_PREVIEW && print_settings) {
+		value = g_new0 (GValue, 1);
+		g_value_init (value, G_TYPE_STRING);
+		g_value_set_string (value, print_settings);
+
+		g_hash_table_insert (args,
+				     g_strdup ("print-settings"),
+				     value);
+		g_free (print_settings);
+		print_settings = NULL;
+	}
+
 	return args;
 }
 
@@ -264,7 +304,12 @@ main (int argc, char *argv[])
 	gboolean enable_metadata = FALSE;
 	GOptionContext *context;
 	GHashTable *args;
+#if WITH_GNOME
 	GnomeProgram *program;
+#else
+	char *accel_filename;
+	GError *error = NULL;
+#endif
 
 	context = g_option_context_new (_("GNOME Document Viewer"));
 
@@ -278,12 +323,27 @@ main (int argc, char *argv[])
 	g_option_context_add_main_entries (context, goption_options, NULL);
 #endif
 
+#if WITH_GNOME
 	program = gnome_program_init (PACKAGE, VERSION,
-                                      LIBGNOMEUI_MODULE, argc, argv,
-                                      GNOME_PARAM_GOPTION_CONTEXT, context,
-                                      GNOME_PARAM_HUMAN_READABLE_NAME, _("Evince"),
+				      LIBGNOMEUI_MODULE, argc, argv,
+				      GNOME_PARAM_GOPTION_CONTEXT, context,
+				      GNOME_PARAM_HUMAN_READABLE_NAME, _("Evince"),
 				      GNOME_PARAM_APP_DATADIR, GNOMEDATADIR,
-                                      NULL);
+				      NULL);
+#else
+	g_option_context_add_group (context, gtk_get_option_group (TRUE));
+	if (!g_option_context_parse (context, &argc, &argv, &error)) {
+		g_warning ("Cannot parse arguments: %s", error->message);
+		g_error_free (error);
+		return 1;
+	}
+	g_option_context_free (context);
+	
+	gnome_vfs_init ();
+
+	accel_filename = g_build_filename (ev_dot_dir (), "accels", NULL);
+	gtk_accel_map_load (accel_filename);
+#endif
 
 	args = arguments_parse ();
 
@@ -291,16 +351,19 @@ main (int argc, char *argv[])
 	if (!ev_application_register_service (EV_APP)) {
 		if (load_files_remote (file_arguments, args)) {
 			g_hash_table_destroy (args);
+#if WITH_GNOME
 			g_object_unref (program);
-			
+#endif
 			return 0;
 		}
 	} else {
 		enable_metadata = TRUE;
 	}
 #endif
-	
+
+#if WITH_GNOME	
 	gnome_authentication_manager_init ();
+#endif
 
 	if (enable_metadata) {
 		ev_metadata_manager_init ();
@@ -318,13 +381,22 @@ main (int argc, char *argv[])
 
 	gtk_main ();
 
+#if WITH_GNOME
 	gnome_accelerators_sync ();
+#else
+	gtk_accel_map_save (accel_filename);
+	g_free (accel_filename);
+#endif
+
 	ev_file_helpers_shutdown ();
 
 	if (enable_metadata) {
 		ev_metadata_manager_shutdown ();
 	}
- 	g_object_unref (program);
 
+#if WITH_GNOME
+ 	g_object_unref (program);
+#endif
+	
 	return 0;
 }
